@@ -122,7 +122,7 @@ class OSBase:
         if not self._arch:
             out, _, ret = safe_run(['dpkg', '--print-architecture'])
             if ret != 0:
-                raise Exception('Running dpkg --print-architecture failed: {}'.format(out))
+                raise RuntimeError('Running dpkg --print-architecture failed: {}'.format(out))
 
             self._arch = out.strip()
         if self._custom_name:
@@ -310,7 +310,14 @@ class OSBase:
         '''
 
         print_info('Saving configuration settings.')
-        data: T.Dict[str, T.Union[str, bool]] = {'Suite': self.suite, 'Architecture': self.arch}
+        data: T.Dict[str, T.Union[str, bool]] = {
+            'Name': self.name,
+            'CustomName': self._custom_name,
+            'Suite': self.suite,
+            'BaseSuite': self.base_suite,
+            'Architecture': self.arch,
+        }
+
         if self.variant:
             data['Variant'] = self.variant
         if mirror:
@@ -387,6 +394,43 @@ class OSBase:
             if https_proxy:
                 f.write('Acquire::https::Proxy "{}";\n'.format(https_proxy))
 
+    def _setup_apt_repo_preferences(self, instance_dir, preferred_suites):
+        '''Setup APT repository preferences.
+        APT somtimes wants to install packages from older repositories to satisfy
+        dependencies, even though we must build with versions from the newer repositories.
+        This especially is the case for `NotAutomatic` suites like "experimental", where packages
+        would not get auto-installed from.
+        Passing "-t <suite>" to the APT commands restricts the solver way too much, so
+        valid dependency chains are no chosen for partial suites if the suites don't
+        contain all dependencies as well.
+        This is a compromise to make APT do the right thing, by simply setting all suites
+        to the same priority.
+        NOTE: With suites like experimental, we may need to set the preferences later if we want
+        to avoid experimental packages being added to the base image. That comes with its own
+        difficulties though, so we avoid that for now.
+        '''
+
+        # enusre all suites are represented in the "preferred suites" list
+        if not preferred_suites:
+            preferred_suites = []
+        if self.has_base_suite:
+            if self.base_suite not in preferred_suites:
+                preferred_suites.insert(0, self.base_suite)
+        if self.suite not in preferred_suites:
+            preferred_suites.insert(0, self.suite)
+
+        aptpref_fname = os.path.join(instance_dir, 'etc', 'apt', 'preferences.d', '10debspawn')
+        with open(aptpref_fname, 'w') as f:
+            first = True
+            for suite in preferred_suites:
+                if not first:
+                    f.write('\n')
+                first = False
+                priority = 500
+                if suite == self.suite:
+                    priority = 600
+                f.write(('Package: *\n' 'Pin: release a={}\n' 'Pin-Priority: {}\n').format(suite, priority))
+
     def _create_internal(
         self,
         mirror=None,
@@ -512,6 +556,9 @@ class OSBase:
                         for line in extra_source_lines.split('\\n'):
                             f.write('{}\n'.format(line.strip()))
 
+            # set preference suites in dependency resolution
+            self._setup_apt_repo_preferences(tdir, extra_suites)
+
             # write our default APT settings for this container
             aptconf_fname = os.path.join(tdir, 'etc', 'apt', 'apt.conf.d', '99debspawn')
             with open(aptconf_fname, 'w') as f:
@@ -745,7 +792,10 @@ class OSBase:
         # read configuration data
         with open(config_fname, 'rt') as f:
             cdata: T.Dict[str, T.Union[str, bool]] = json.loads(f.read())
+            self._name = cdata.get('Name', self.name)
+            self._custom_name = cdata.get('CustomName', self._custom_name)
             self._suite = cdata.get('Suite', self.suite)
+            self._base_suite = cdata.get('BaseSuite', self.base_suite)
             self._arch = cdata.get('Architecture', self.arch)
             self._variant = cdata.get('Variant', self.variant)
             mirror = cdata.get('Mirror')
